Bug fixes, improvements and editing files.

- [X] fix tasks missing from `--summary --relative`
- [X] remove slashes from columns in summary, its just visual noise
- [X] `-e`/`--edit` to open matching task files in editor at the line
      number of the first match
